@@ -26,6 +26,7 @@ import java.awt.Font;
 import java.awt.Graphics2D;
 import java.awt.KeyboardFocusManager;
 import java.awt.Window;
+import java.awt.event.ActionEvent;
 import java.awt.event.FocusEvent;
 import java.awt.event.FocusListener;
 import java.awt.event.HierarchyEvent;
@@ -68,7 +69,9 @@ import org.freeplane.features.attribute.ColumnWidthChangeEvent;
 import org.freeplane.features.attribute.IAttributeTableModel;
 import org.freeplane.features.attribute.IColumnWidthChangeListener;
 import org.freeplane.features.attribute.NodeAttributeTableModel;
+import org.freeplane.features.format.FormattedObject;
 import org.freeplane.features.format.IFormattedObject;
+import org.freeplane.features.format.PatternFormat;
 import org.freeplane.features.link.LinkController;
 import org.freeplane.features.map.MapController;
 import org.freeplane.features.map.NodeModel;
@@ -81,7 +84,6 @@ import org.freeplane.features.text.mindmapmode.EditNodeBase.EditedComponent;
 import org.freeplane.features.text.mindmapmode.EditNodeBase.IEditControl;
 import org.freeplane.features.text.mindmapmode.MTextController;
 import org.freeplane.features.ui.ViewController;
-import org.freeplane.features.url.UrlManager;
 import org.freeplane.view.swing.map.MapView;
 import org.freeplane.view.swing.map.NodeView;
 
@@ -329,7 +331,7 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 				final int xmax = linkIcon != null ? linkIcon.getIconWidth() : 0;
 				final int x = me.getX() - getColumnModel().getColumn(0).getWidth();
 				if(x < xmax){
-					UrlManager.getController().loadURL(uri);
+					LinkController.getController().loadURL(attributeView.getNode(), new ActionEvent(me.getSource(), me.getID(), null), uri);
 					return false;
 				}
              }
@@ -823,13 +825,11 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		       // Take in the new value
 	        TableCellEditor editor = getCellEditor();
 	        if (editor != null) {
-	            Object value = editor.getCellEditorValue();
+	            final Object value = editor.getCellEditorValue();
 				if (value != null) {
-					final MTextController textController = (MTextController) TextController.getController();
-					final Object oldValue = getValueAt(editingRow, editingColumn);
-					final String pattern  = oldValue instanceof IFormattedObject
-					        ? ((IFormattedObject) oldValue).getPattern() : null;
-					setValueAt(textController.guessObjectOrURI(value, pattern), editingRow, editingColumn);
+					final String pattern = extractPatternIfAvailable(getValueAt(editingRow, editingColumn));
+                    final Object newValue = enforceFormattedObjectForIdentityPattern(value, pattern);
+                    setValueAt(newValue, editingRow, editingColumn);
 				}
 	            removeEditor();
 	        }
@@ -839,6 +839,18 @@ class AttributeTable extends JTable implements IColumnWidthChangeListener {
 		}
     }
 
+    private String extractPatternIfAvailable(final Object oldValue) {
+        return oldValue instanceof IFormattedObject ? ((IFormattedObject) oldValue).getPattern() : null;
+    }
+
+    // unfortunately we have to handle IDENTITY_PATTERN explicitely since (only) attributes
+    // have no place for the format except for the value itself - so we need a FormattedObject here
+    private Object enforceFormattedObjectForIdentityPattern(Object value, final String pattern) {
+        final MTextController textController = (MTextController) TextController.getController();
+        return PatternFormat.IDENTITY_PATTERN.equals(pattern) ? new FormattedObject(value, pattern) : textController
+            .guessObjectOrURI(value, pattern);
+    }
+
 	@Override
     public void setValueAt(Object aValue, int row, int column) {
 	    super.setValueAt(column == 0 ? aValue.toString() : aValue, row, column);
